#!/usr/bin/env python
#
# This file is part of Learning Elements
# Author(s): Giselle Flores and Cecilia Prieto, Girlstart
# Copyright 2008
#
# Source code is derived from Girlstart's Project IT Girl Game Templates:
# http://itgirl.dreamhosters.com/itgirlgames/, http://www.girlstart.org/itgirl
# See the credits file for image sources.
#
# Learning Elements is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Learning Elements is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Learning Elements.  If not, see <http://www.gnu.org/licenses/>.

import pygame, random
from helpers import *

class Activities(pygame.sprite.Sprite):
	def __init__(self,background_image):
		pygame.sprite.Sprite.__init__(self)
		self.screen = pygame.display.get_surface()
		self.area = self.screen.get_rect()
		self.background = background_image

		self.effectimage, self.effectimagerect = load_image('chemistry1.bmp')
		self.original_width = self.effectimage.get_width()
		self.original_height = self.effectimage.get_height()
		
		#Set up sound
		self.incorrect_sound=load_sound("siren4.wav")
		self.correcteffectimage, self.correcteffectimagerect = load_image('chemistry3.bmp')
		self.correcteffectimagerect.centerx, self.correcteffectimagerect.centery = self.area.centerx, self.area.centery
		self.incorrecteffectimage, self.incorrecteffectimagerect = load_image('chemistry2.bmp')
		self.incorrecteffectimagerect.centerx, self.incorrecteffectimagerect.centery = self.area.centerx, self.area.centery
		
		self.score = 0
		self.correct = True
		
	def check_answer(self, correct):
		# The user has answered.  Display the results of their answer.  Remember, we need to redraw the background
		# in order to get rid of the previous stuff drawn to the screen.
		font = pygame.font.Font("data/fonts/Breip.ttf", 50)
		
		if correct:
			self.screen.blit(self.background, (0, 0))
			self.screen.blit(self.correcteffectimage,self.correcteffectimagerect)
			text = font.render("Correct!  Press any key to continue", 1, (0,128,0))
			textrect = text.get_rect()
			textrect.centerx, textrect.centery = self.area.centerx,500
			self.screen.blit(text, textrect)
		elif not correct:
			self.screen.blit(self.background, (0, 0))
			self.incorrect_sound.play()
			self.screen.blit(self.incorrecteffectimage,self.incorrecteffectimagerect)
			text = font.render("Sorry, that's not correct.", 1, (255,255,0))
			textrect = text.get_rect()
			textrect.centerx, textrect.centery = self.area.centerx,100
			self.screen.blit(text, textrect)

			text = font.render("Press any key to continue.", 1, (255,255,0))
			textrect = text.get_rect()
			textrect.centerx, textrect.centery = self.area.centerx,500
			self.screen.blit(text, textrect)
						
		pygame.display.flip()
		
		# Now, wait for the user to click a key to continue:
		answered = False
		while not answered:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					answered = True				
		
	def see_effect(self):
		# change the size of the image based on the player's score
		new_width = 20*self.score + self.original_width
		new_height = 20*self.score + self.original_height
		effectimage = pygame.transform.scale(self.effectimage, (self.original_width, self.original_height))

		effectimagerect = self.effectimage.get_rect()
		effectimagerect.centerx = self.area.centerx
		effectimagerect.centery = self.area.centery

		self.screen.blit(effectimage,effectimagerect)
		
	def decision1(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is the element's name for Li?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Lanthanum", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Thallium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Lithium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()

	def decision2(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What's the element's name for Mg?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Magnesium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Manganese", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Mercury", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()

	def decision3(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is the element's name for Au?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Aluminum", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Gold", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Silver", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()

	def decision4(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is the element's name for K?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Krypton", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Polonium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Potassium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()

	def decision5(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is the element's name for B?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Bromine", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Boron", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Beryllium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()

	def decision6(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is the element's name for H?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Hydrogen", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Holmium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Helium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()

	def decision7(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is the element's name for Fe?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Fluorine", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Iridium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Iron", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()

	def decision8(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is the element's name for Ga?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Gallium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Germanium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Gadolinium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()

	def decision9(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is the element's name for Cl?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Cobalt", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Chlorine", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Chromium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()

	def decision10(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is the element's name for O?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Oxygen", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Osmium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Xenon", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()
			
	def decision11(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is the element's name for N?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Neodymium", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Nitrogen", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Neon", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()
			
	def decision12(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is Flourine's Chemical symbol?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) F", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Fe", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Fr", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()
			
	def decision13(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is Phosphorus' Chemical symbol?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Pr", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Pu", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) P", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()
			
	def decision14(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is Tin's Chemical symbol?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Ti", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Sn", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Tl", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()
			
	def decision15(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is Nickel's Chemical symbol?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Ne", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) N", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Ni", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()
			
	def decision16(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is Zinc's Chemical symbol?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Zn", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Sn", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Zr", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()
			
	def decision17(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is Copper's Chemical symbol?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Cr", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Cu", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Co", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()
			
	def decision18(self):
		decision_made = False
		
		while not decision_made:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == pygame.K_a:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_b:
						self.score = self.score + 0
						self.check_answer(False)
						decision_made = True
					elif event.key == pygame.K_c:
						self.score = self.score + 1
						self.check_answer(True)
						decision_made = True
		
			if not decision_made:
				# Draw everything to the screen
				self.screen.blit(self.background, (0, 0))

				font = pygame.font.Font("data/fonts/Breip.ttf", 30)

				text = font.render("What is Argon's Chemical symbol?", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = self.area.top
				self.screen.blit(text, textrect)

				text = font.render("a) Ag", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 450
				self.screen.blit(text, textrect)

				text = font.render("b) Au", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 500
				self.screen.blit(text, textrect)

				text = font.render("c) Ar", 1, (255,0,0))
				textrect = text.get_rect()
				textrect.centerx = self.area.centerx
				textrect.top = 550
				self.screen.blit(text, textrect)

				self.see_effect()
			
			pygame.display.flip()
